==> qtjambi-xml-6.6.0-sources.jar: io/qt/xml/QDomComment.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents an XML comment</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qdomcomment.html">QDomComment</a></code></p>
 */
public class QDomComment extends io.qt.xml.QDomCharacterData
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomcomment.html#QDomComment">QDomComment::<wbr>QDomComment()</a></code></p>
     */
    public QDomComment(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomComment instance);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomcomment.html#QDomComment-1">QDomComment::<wbr>QDomComment(QDomComment)</a></code></p>
     */
    public QDomComment(io.qt.xml.@NonNull QDomComment x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomComment instance, io.qt.xml.QDomComment x);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomcomment.html#operator-eq">QDomComment::<wbr>operator=(QDomComment)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomComment arg__1){
        assign_native_cref_QDomComment(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomComment(long __this__nativeId, long arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QDomComment(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QDomComment clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomComment clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.7.1-sources.jar: io/qt/xml/QDomComment.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents an XML comment</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qdomcomment.html">QDomComment</a></code></p>
 */
public class QDomComment extends io.qt.xml.QDomCharacterData
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomcomment.html#QDomComment">QDomComment::<wbr/>QDomComment()</a></code></p>
     */
    public QDomComment(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomComment instance);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomcomment.html#QDomComment-1">QDomComment::<wbr/>QDomComment(QDomComment)</a></code></p>
     */
    public QDomComment(io.qt.xml.@NonNull QDomComment x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomComment instance, io.qt.xml.QDomComment x);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomcomment.html#operator-eq">QDomComment::<wbr/>operator=(QDomComment)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomComment arg__1){
        assign_native_cref_QDomComment(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomComment(long __this__nativeId, long arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QDomComment(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code><a href="https://doc.qt.io/qt/qdomcomment.html#QDomComment-1">QDomComment::<wbr/>QDomComment(QDomComment)</a></code></p>
     */
    @QtUninvokable
    @Override
    public QDomComment clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomComment clone_native(long __this_nativeId);
}
